/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.oozie.executor.jpa;

import java.util.List;
import java.util.Objects;

import javax.persistence.EntityManager;
import javax.persistence.Query;

import org.apache.oozie.CoordinatorActionBean;
import org.apache.oozie.ErrorCode;

/**
 * Load the CoordinatorAction into a Bean and return it.
 */
public class CoordActionGetJPAExecutor implements JPAExecutor<CoordinatorActionBean> {

    private String coordActionId = null;

    public CoordActionGetJPAExecutor(String coordActionId) {
        this.coordActionId = Objects.requireNonNull(coordActionId, "coordActionId cannot be null");
    }

    @Override
    public String getName() {
        return "CoordActionGetJPAExecutor";
    }

    @Override
    @SuppressWarnings("unchecked")
    public CoordinatorActionBean execute(EntityManager em) throws JPAExecutorException {
        List<CoordinatorActionBean> caBeans;
        try {
            Query q = em.createNamedQuery("GET_COORD_ACTION");
            q.setParameter("id", coordActionId);
            caBeans = q.getResultList();
        }
        catch (Exception e) {
            throw new JPAExecutorException(ErrorCode.E0603, e.getMessage(), e);
        }
        CoordinatorActionBean bean = null;
        if (caBeans != null && caBeans.size() > 0) {
            bean = caBeans.get(0);
            return bean;

        }
        else {
            throw new JPAExecutorException(ErrorCode.E0605, coordActionId);
        }
    }
}
