/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.oozie.service;

import java.util.Arrays;

enum ActionConfFileType {
    XML(".xml"),
    PROPERTIES(".properties");

    private final String extension;

    ActionConfFileType(String extension) {
        this.extension = extension;
    }

    public String getExtension() {
        return this.extension;
    }

    static boolean isSupportedFileType(String fileName) {
        for (ActionConfFileType actionConfFileType : values()) {
            if (fileName.endsWith(actionConfFileType.getExtension())) {
                return true;
            }
        }
        return false;
    }

    static ActionConfFileType getFileType(String fileName) {
        for (ActionConfFileType actionConfFileType : values()) {
            if (fileName.endsWith(actionConfFileType.getExtension())) {
                return actionConfFileType;
            }
        }
        throw new UnsupportedOperationException(String.format(
            "Unsupported action conf file extension for file %s, supported extension are %s", fileName,
                String.join(", ", names())));
    }

    public static String[] names() {
        return Arrays.toString(values()).replaceAll("^.|.$", "").split(", ");
    }
}
