/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.oozie.server.guice;

import com.google.inject.Inject;
import com.google.inject.Provider;
import org.eclipse.jetty.rewrite.handler.RedirectPatternRule;
import org.eclipse.jetty.rewrite.handler.RewriteHandler;

class RewriteHandlerProvider implements Provider<RewriteHandler> {
    private final RewriteHandler rewriteHandler;

    @Override
    public RewriteHandler get() {
        return rewriteHandler;
    }

    @Inject
    public RewriteHandlerProvider(final RedirectPatternRule redirectPatternRule) {
        this.rewriteHandler = new RewriteHandler();

        redirectPatternRule.setPattern("");
        redirectPatternRule.setLocation("/oozie");
        redirectPatternRule.setTerminating(true);

        this.rewriteHandler.addRule(redirectPatternRule);
    }
}
